/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.deployer.api;

import java.util.List;

import org.ow2.util.ee.deploy.api.deployer.IDeployer;
import org.ow2.util.ee.deploy.api.deployer.IDeployerManager;
import org.ow2.util.ee.deploy.api.deployer.UnsupportedDeployerException;
import org.ow2.util.plan.bindings.deploymentplan.Deployment;
import org.ow2.util.plan.deploy.deployable.api.DeploymentPlanDeployable;
import org.ow2.util.plan.fetcher.api.IResourceFetcherFactoryManager;
import org.ow2.util.plan.monitor.api.IResourceMonitor;
import org.ow2.util.plan.reader.plan.IPlanReader;

/**
 * Interface for deployment plans deployer.
 * @author mleduque
 */
public interface IDeploymentPlanDeployer extends IDeployer<DeploymentPlanDeployable> {
    /**
     * Sets the planReader.
     * @param planReader the new planReader.
     */
    void setPlanReader(IPlanReader planReader);

    /**
     * Gets the planReader.
     * @return the PlanReader.
     */
    IPlanReader getPlanReader();

    /**
     * Sets the fetcher factories manager.
     * @param factoryManager the new fetcher factories manager.
     */
    void setFetcherFactoryManager(IResourceFetcherFactoryManager factoryManager);

    /**
     * Returns the fetcher factories manager.
     * @return the the fetcher factories manager.
     */
    IResourceFetcherFactoryManager getFetcherFactoryManager();

    /**
     * Sets the deployer manager.
     * @param deployerManager the new deployer manager.
     */
    void setDeployerManager(IDeployerManager deployerManager);

    /**
     * Returns the deployer manager.
     * @return the deployer manager.
     */
    IDeployerManager getDeployerManager();

    /**
     * Gives the number of deployed deployment plans.
     * @return the number of deployed deployment plans.
     */
    Integer getDeploymentPlansCount();

    /**
     * Gives the path of the deployed deployment plans.
     * @return the path of the deployed deployment plans.
     */
    List<String> getDeploymentPlansUrls();

    /**
     * Returns the list of deployed deployment plans Ids.
     * @return the list of deployed deployment plans Ids.
     */
    List<String> getDeploymentPlansIds();

    /**
     * Sets the resource monitor.
     * @param resourceMonitor the new resource monitor.
     */
    void setResourceMonitor(IResourceMonitor resourceMonitor);

    /**
     * Returns the resource monitor.
     * @return the resource monitor.
     */
    IResourceMonitor getResourceMonitor();

    /**
     * Deploys a deployment.
     * @param deployment the deployment.
     * @throws FragmentDeploymentException if deployment was not successful.
     * @throws UnsupportedDeployerException any.
     */
    void deployDeployment(Deployment deployment) throws FragmentDeploymentException, UnsupportedDeployerException;

    /**
     * Undeploy a deployment.
     * @param deployment the deployment.
     * @throws FragmentUndeploymentException if undeployment was not successful.
     */
    void undeployDeployment(Deployment deployment) throws FragmentUndeploymentException;

    /**
     * Returns the deployment plan deployable that owns the deployment, or null if none could be found.
     * @param deployment the deployment.
     * @return the owner deployment plan deployable.
     */
    DeploymentPlanDeployable getOwnerDeploymentPlanDeployable(Deployment deployment);
}
