/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.deployer.impl.condition.script;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;

import javax.script.ScriptEngine;
import javax.script.ScriptEngineFactory;
import javax.script.ScriptException;

/**
 * A {@code RhinoScriptEngineFactory} is ...
 *
 * @author Guillaume Sauthier
 */
public class RhinoScriptEngineFactory extends ForwardingScriptEngineFactory {

    private static final String ENVIRONMENT_JS = "environment.js";
    private ScriptEngineFactory scriptEngineFactory;

    public void setScriptEngineFactory(ScriptEngineFactory scriptEngineFactory) {
        if (!isJavaScriptEngine(scriptEngineFactory)) {
            throw new RuntimeException("Expecting a JavaScript engine");
        }
        this.scriptEngineFactory = scriptEngineFactory;
    }

    private boolean isJavaScriptEngine(ScriptEngineFactory scriptEngineFactory) {
        for (String mimeType : scriptEngineFactory.getMimeTypes()) {
            if ("application/javascript".equals(mimeType)) {
                return true;
            }
        }
        return false;
    }

    @Override
    protected ScriptEngineFactory delegate() {
        return scriptEngineFactory;
    }

    @Override
    public ScriptEngine getScriptEngine() {
        ScriptEngine engine = super.getScriptEngine();

        // Fill the engine with pre-defined functions
        evaluateResource(engine, "SystemPropertyInfo.js");
        evaluateResource(engine, ENVIRONMENT_JS);

        return engine;
    }

    private void evaluateResource(final ScriptEngine engine, final String resourceName) {
        evaluateResource(engine, RhinoScriptEngineFactory.class, resourceName);
    }

    protected void evaluateResource(final ScriptEngine engine,
                                    final Class<?> site,
                                    final String resourceName) {
        Reader reader = null;
        try {
            reader = getResourceReader(site, resourceName);
            engine.eval(reader);
        } catch (ScriptException e) {
            throw new RuntimeException("Cannot execute script " + resourceName, e);
        } catch (IOException e) {
            throw new RuntimeException("Cannot load script " + resourceName, e);
        } finally {
            if (reader != null) {
                try {
                    reader.close();
                } catch (IOException e) {
                    // Ignored
                }
            }
        }
    }

    private Reader getResourceReader(final Class<?> site, final String name) throws IOException {
        InputStream is = site.getResourceAsStream(name);
        if (is == null) {
            throw new IOException("Cannot load resource '" + name + "' from " + site);
        }
        return new InputStreamReader(is);
    }


}
