/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.deployer.impl.condition;

import javax.script.ScriptEngine;
import javax.script.ScriptEngineFactory;
import javax.script.ScriptEngineManager;

import org.ow2.util.plan.deployer.impl.condition.script.RhinoScriptEngineFactory;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

import static org.testng.Assert.assertFalse;
import static org.testng.Assert.assertNotNull;
import static org.testng.Assert.assertNull;
import static org.testng.Assert.assertTrue;

/**
 * A {@code ScriptConditionEvaluatorTestCase} is ...
 *
 * @author Guillaume Sauthier
 */
public class ScriptConditionEvaluatorTestCase {

    private ScriptConditionEvaluator evaluator;

    @BeforeMethod
    public void setUp() throws Exception {
        ScriptEngineManager manager = new ScriptEngineManager();
        ScriptEngine engine = manager.getEngineByName("JavaScript");
        ScriptEngineFactory factory = engine.getFactory();

        RhinoScriptEngineFactory rhino = new RhinoScriptEngineFactory();
        rhino.setScriptEngineFactory(factory);

        evaluator = new ScriptConditionEvaluator();
        evaluator.setScriptEngineFactory(rhino);
    }

    @Test
    public void testTrueFalseAssessmentWithNullAndNonNullValues() throws Exception {
        // a null value will produce a false evaluation
        assertFalse(evaluator.evaluate("null"));
        assertFalse(evaluator.evaluate("undefined"));
        // any non-null value will produce a true evaluation
        assertTrue(evaluator.evaluate("'a'"));
        assertTrue(evaluator.evaluate("1"));
    }

    @Test
    public void testTrueFalseAssessmentWithBooleanValues() throws Exception {
        assertTrue(evaluator.evaluate("true"));
        assertFalse(evaluator.evaluate("false"));
    }
}
