/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.deployer.test;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertFalse;
import static org.testng.Assert.assertTrue;

import java.io.File;

import org.ow2.util.archive.api.IFileArchive;
import org.ow2.util.archive.impl.ArchiveManager;
import org.ow2.util.ee.deploy.api.deployable.IDeployable;
import org.ow2.util.ee.deploy.impl.deployer.DeployerManager;
import org.ow2.util.ee.deploy.impl.helper.DeployableHelper;
import org.ow2.util.ee.deploy.api.deployable.factory.IFileDeployableFactoryManager;
import org.ow2.util.ee.deploy.api.deployable.factory.XmlFileDeployableFactory;
import org.ow2.util.plan.deploy.deployable.impl.DeploymentPlanDeployableImpl;
import org.ow2.util.plan.deploy.deployable.impl.RepositoryDeployableImpl;
import org.ow2.util.ee.deploy.impl.deployable.factory.DefaultFileDeployableFactoryManager;
import org.ow2.util.ee.deploy.impl.deployable.factory.XmlFileDeployableFactoryImpl;
import org.ow2.util.plan.deployer.impl.DeploymentPlanDeployer;
import org.ow2.util.plan.fetcher.impl.ResourceFetcherFactoryManagerImpl;
import org.ow2.util.plan.reader.plan.PlanReaderImpl;
import org.testng.annotations.Test;

/**
 * Test class for the deployment plan deployer.
 * We'd have to import too much from other projects to really
 * test the deployment with real deployables, so the test is done
 * on a empty plan.
 * @author mleduque
 */
public class EmptyDeploymentPlanTest {

    private static final String DEPLOYMENTPLAN_XML_PATH =
        "target/test-classes/empty-deployment-plan.xml";

    private static final String DEPLOYMENTPLAN_NS =
    "http://jonas.ow2.org/ns/deployment-plan/1.0";
    private static final String REPOSITORY_NS =
    "http://jonas.ow2.org/ns/deployment/repositories/1.0";

    private XmlFileDeployableFactory factory = null;
    private IFileDeployableFactoryManager manager = null;

    private DeployerManager deployerManager = null;
    private DeploymentPlanDeployer deploymentPlanDeployer = null;

    private IDeployable deployable = null;
    private IFileArchive planArchive = null;


    @Test
    public EmptyDeploymentPlanTest() throws Exception {
        // ClassCastException
        planArchive = (IFileArchive)ArchiveManager.getInstance().getArchive(
                new File(DEPLOYMENTPLAN_XML_PATH));

        factory = new XmlFileDeployableFactoryImpl();
        manager = new DefaultFileDeployableFactoryManager();
        manager.addFileDeployableFactory(factory);
        DeployableHelper.setFileDeployableFactory(manager);

        factory.registerFileDeployable(
                DeploymentPlanDeployableImpl.class,
                DEPLOYMENTPLAN_NS);
        factory.registerFileDeployable(
                RepositoryDeployableImpl.class,
                REPOSITORY_NS);

        deploymentPlanDeployer = new DeploymentPlanDeployer();
        deploymentPlanDeployer.setPlanReader(new PlanReaderImpl());
        deploymentPlanDeployer.setFetcherFactoryManager(
                new ResourceFetcherFactoryManagerImpl());

        deployerManager = new DeployerManager();
        deployerManager.register(deploymentPlanDeployer);
        deploymentPlanDeployer.setDeployerManager(deployerManager);

        planArchive = (IFileArchive)ArchiveManager.getInstance().getArchive(
                new File(DEPLOYMENTPLAN_XML_PATH));

        deployable = DeployableHelper.getDeployable(planArchive);
        assertEquals(deployable.getClass(), DeploymentPlanDeployableImpl.class);
    }

    @Test
    public void deployEmptyPlan() throws Exception {
        deploymentPlanDeployer.deploy(deployable);
        assertTrue(deploymentPlanDeployer.isDeployed(deployable));
        deploymentPlanDeployer.undeploy(deployable);
        assertFalse(deploymentPlanDeployer.isDeployed(deployable));
    }

    @Test
    public void deployEmptyPlanWithManager() throws Exception {
        deployerManager.deploy(deployable);
        //assertTrue(deployerManager.isDeployed(deployable));
        deployerManager.undeploy(deployable);
        //assertFalse(deployerManager.isDeployed(deployable));
    }

}
