/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.fetcher.api;

import java.io.File;

import org.ow2.util.plan.bindings.deploymentplan.DeploymentPlanFragment;
import org.ow2.util.plan.fetcher.api.exceptions.FetcherFactoryException;
import org.ow2.util.plan.repository.api.IRepositoryManager;

/**
 * An interface for factories for ResourceFetcher objects.
 * @author Mickaël LEDUQUE
 */
public interface IResourceFetcherFactory {

    /**
     * Returns a non resolved resource fetcher suitable for this deployment.
     * @param fragment the fragment.
     * @return a matching resource fetcher.
     * @throws FetcherFactoryException
     */
    public IResourceFetcher getResourceFetcher(DeploymentPlanFragment fragment)
                    throws FetcherFactoryException;

    /**
     * Gives the supported Deployment plan fragment class for this factory.
     * @return the supported deployment class.
     */
    public Class<? extends DeploymentPlanFragment> getSupportedClass();

    /**
     * Sets the class that will be used to instanciate resource fetchers.
     * @param clazz the class used.
     */
    public void setFetcherConcreteClass(Class<? extends IResourceFetcher> clazz);

    /**
     * Returns the class that will be used to instanciate resource fetchers.
     * @return the class used.
     */
    public Class<? extends IResourceFetcher> getFetcherConcreteClass();

    /**
     * Sets the repository manager used by this factory.
     * @param repositoryManager the new repository manager.
     */
    public void setRepositoryManager(IRepositoryManager repositoryManager);

    /**
     * Returns the repository manager used by this factory.
     * @return the repository manager.
     */
    public IRepositoryManager getRepositoryManager();

    /**
     * Sets the local repositories base directory, used to keep the local copy of
     * the resource.
     * @param localDirectory the new local directory.
     */
    public void setLocalRepositoriesBaseDir(File localRepositoriesBaseDir);
}
