/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.fetcher.api;

import org.ow2.util.plan.bindings.deploymentplan.DeploymentPlanFragment;
import org.ow2.util.plan.bindings.exceptions.InvalidDeploymentException;
import org.ow2.util.plan.fetcher.api.exceptions.FetcherFactoryException;
import org.ow2.util.plan.fetcher.api.exceptions.ResourceNotFoundException;

/**
 * Manages a list of ResourceFetcher factories that allows it to
 * find a matching factories for deployments. 
 * @author Mickaël LEDUQUE
 */
public interface IResourceFetcherFactoryManager extends Iterable<IResourceFetcherFactory> {

    /**
     * Returns a local file, usable by the deployer, for the given deployment plan fragment.
     * @param deployment the deployment.
     * @return a local file for the deployment.
     * @throws ResourceNotFoundException if the resource couldn't be found on the repositories.
     * @throws InvalidDeploymentException if deployment is not valid.
     */
    public IResourceFetcher getResourceFetcher(DeploymentPlanFragment deployment) throws ResourceNotFoundException, InvalidDeploymentException, FetcherFactoryException;

    /**
     * Adds a ResourceFetcher factory to the managed factories.
     * @param factory the factory to be added.
     */
    public void addResourceFetcherFactory(IResourceFetcherFactory factory);

    /**
     * Removes a ResourceFetcher factory from the managed factories.
     * @param factory the factory to be removed.
     */
    public void removeResourceFetcherFactory(IResourceFetcherFactory factory);

    /**
     * Finds a ResourceFetcher factory that can be used for the given deployment.
     * @param fragment the deployment fragment.
     * @return the factory.
     */
    public IResourceFetcherFactory findFetcherFactoryForDeployment(DeploymentPlanFragment fragment);


}
