/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.fetcher.impl.obr;

import org.osgi.framework.BundleContext;
import org.ow2.util.plan.bindings.deploymentplan.DeploymentPlanFragment;
import org.ow2.util.plan.bindings.deploymentplan.obr.ObrDeployment;
import org.ow2.util.plan.fetcher.api.IResourceFetcher;
import org.ow2.util.plan.fetcher.api.IResourceFetcherFactory;
import org.ow2.util.plan.fetcher.api.exceptions.FetcherFactoryException;
import org.ow2.util.plan.fetcher.impl.AbsResourceFetcherFactoryImpl;

/**
 * Factory of ObrResourceFetcher objects.
 * @author Mickaël LEDUQUE
 */
public class ObrResourceFetcherFactory extends AbsResourceFetcherFactoryImpl implements IResourceFetcherFactory {

    /**
     * The bundle context.
     */
    private BundleContext bundleContext = null;

    /**
     * Default constructor.
     */
    public ObrResourceFetcherFactory() {
        this.setFetcherConcreteClass(ObrResourceFetcher.class);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public IResourceFetcher getResourceFetcher(final DeploymentPlanFragment fragment) throws FetcherFactoryException {
        ObrResourceFetcher obrResourceFetcher = (ObrResourceFetcher) super.getResourceFetcher(fragment);
        obrResourceFetcher.setBundleContext(this.bundleContext);
        return obrResourceFetcher;
    }

    /**
     * {@inheritDoc}
     */
    public Class<? extends DeploymentPlanFragment> getSupportedClass() {
        return ObrDeployment.class;
    }

    /**
     * Sets the bundle context.
     * @param bundleContext the new bundle context.
     */
    public void setBundleContext(final BundleContext bundleContext) {
        this.bundleContext = bundleContext;
    }

    /**
     * Returns the bundle context.
     * @return the bundle context.
     */
    public BundleContext getBundleContext() {
        return this.bundleContext;
    }
}
