/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.monitor.api;

import java.util.List;

import org.ow2.util.plan.bindings.deploymentplan.DeploymentPlanFragment;
import org.ow2.util.plan.fetcher.api.IResourceFetcher;

/**
 * Interface for the resource monitor.
 * @author Mickaël LEDUQUE
 */
public interface IResourceMonitor {

    /**
     * Adds a resource to be monitored.
     * @param resourceFetcher the fetcher for the monitored resource.
     */
    void addMonitoredResource(IResourceFetcher resourceFetcher);

    /**
     * Removes a monitored resource.
     * @param deployment the removed resource.
     */
    void removeMonitoredResource(DeploymentPlanFragment deployment);

    /**
     * Removes a monitored resource by its resource fetcher.
     * @param resourceFetcher the fetcher for the removed resource.
     */
    void removeMonitoredResource(IResourceFetcher resourceFetcher);

    /**
     * Checks if some resources has changed. Return the changed ones.
     * @return the list of resources that changed.
     */
    List<IResourceFetcher> getChangedResources();

    /**
     * Returns the number of monitored resources.
     * @return the number of monitored resources.
     */
    Integer getMonitoredResourcesCount();

    /**
     * Gives the descriptions of the monitored resources.
     * @return the descriptions of the monitored resources.
     */
    List<String> getMonitoredResourcesDescriptions();
}
