/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.monitor.impl;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;
import org.ow2.util.plan.bindings.deploymentplan.DeploymentPlanFragment;
import org.ow2.util.plan.fetcher.api.IResourceFetcher;
import org.ow2.util.plan.fetcher.api.exceptions.FetcherException;
import org.ow2.util.plan.monitor.api.IResourceMonitor;

/**
 * Implementation for the resource monitor.
 * @author Mickaël LEDUQUE
 */
public class ResourceMonitorImpl implements IResourceMonitor {

    /**
     * The logger.
     */
    private Log logger = LogFactory.getLog(ResourceMonitorImpl.class);

    /**
     * The monitored resources.
     */
    private List<IResourceFetcher> monitoredResources = new ArrayList<IResourceFetcher>();

    /**
     * {@inheritDoc}
     */
    public void addMonitoredResource(IResourceFetcher resourceFetcher) {
        monitoredResources.add(resourceFetcher);
    }

    /**
     * {@inheritDoc}
     */
    public void removeMonitoredResource(DeploymentPlanFragment deployment) {
        for (IResourceFetcher fetcher : monitoredResources) {
            if ((fetcher.getDeployment()).equals(deployment)) {
                monitoredResources.remove(fetcher);
                return;
            }
        }
    }

    /**
     * {@inheritDoc}
     */
    public List<IResourceFetcher> getChangedResources() {
        List<IResourceFetcher> result = new ArrayList<IResourceFetcher>();

        for (IResourceFetcher fetcher : this.monitoredResources) {
            try {
                if (fetcher.hasChanged()) {
                    result.add(fetcher);
                }
            } catch (FetcherException e) {
                logger.warn("Exception while checking resource {0} ; exception: {1}",
                        fetcher.getDeployment(), e);
            }
        }

        return result;
    }

    /**
     * {@inheritDoc}
     */
    public Integer getMonitoredResourcesCount() {
        return this.monitoredResources.size();
    }

    /**
     * {@inheritDoc}
     */
    public List<String> getMonitoredResourcesDescriptions() {
        List<String> result = new ArrayList<String>();
        for (IResourceFetcher fetcher : monitoredResources) {
            result.add(fetcher.toString());
        }
        return result;
    }

    /**
     * {@inheritDoc}
     */
    public void removeMonitoredResource(IResourceFetcher resourceFetcher) {
        monitoredResources.remove(resourceFetcher);
    }

}
