/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.repository.api;

import java.util.Iterator;

import org.ow2.util.plan.bindings.exceptions.InvalidRepositoryException;
import org.ow2.util.plan.bindings.repository.Repository;

/**
 * Interface for the repository managers.
 * @author Mickaël LEDUQUE
 */
public interface IRepositoryManager extends Iterable<Repository> {

    /**
     * Add a repository to the managed ones.
     * @param repository the added repository
     * @throws RepositoryIdCollisionException when a repository with the same id is already in the manager.
     * @throws InvalidRepositoryException when the repository is not valid.
     */
    public void addRepository(final Repository repository)
            throws RepositoryIdCollisionException, InvalidRepositoryException;

    /**
     * Removes a repository from the managed ones.
     * @param repositoryId the id of the repository to be removed.
     */
    public void removeRepository(final Repository repository);

    /**
     * Returns the repository with the given id.
     * @param id the id of the wanted repository.
     * @return the repository with the matching id.
     */
    public Repository getRepositoryById(String id);

    /**
     * Returns an iterator over the repositories in the manager.
     * The iterator is sorted in order to get the local repositories first.
     * @return the iterator.
     */
    public Iterator<Repository> iterator();

    /**
     * Returns the number of repositories in the manager.
     * @return the number of repositories.
     */
    public Integer getRepositoryCount();
}
