/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.repository.impl;

import java.util.Arrays;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import org.ow2.util.plan.bindings.exceptions.InvalidRepositoryException;
import org.ow2.util.plan.bindings.repository.Repository;
import org.ow2.util.plan.repository.api.IRepositoryManager;
import org.ow2.util.plan.repository.api.RepositoryIdCollisionException;

/**
 *
 * @author Mickaël LEDUQUE
 */
public abstract class AbsRepositoryManagerImpl implements IRepositoryManager {

    /**
     * The managed repositories.
     */
    protected Map<String, Repository> repositories = new HashMap<String, Repository>();

    /**
     * {@inheritDoc}
     */
    public void addRepository(final Repository repository)
                    throws RepositoryIdCollisionException, InvalidRepositoryException {
        String repositoryId = repository.getId();
        if (repositoryId == null) {
            throw new InvalidRepositoryException("The repository has no id; repository: "
                    + repository);
        }
        if (this.repositories.containsKey(repositoryId)) {
            throw new RepositoryIdCollisionException("Repository Id already used:"
                    + repositoryId);
        }
        this.repositories.put(repositoryId, repository);
    }

    /**
     * {@inheritDoc}
     */
    public void removeRepository(final Repository repository) {
        /* Must make sure the repository in the manager is the same */
        Repository matchingRepository = this.repositories.get(repository.getId());
        if (repository == matchingRepository) {
            this.repositories.remove(repository.getId());
        }
    }

    /**
     * {@inheritDoc}
     */
    public Repository getRepositoryById(final String id) {
        return this.repositories.get(id);
    }

    /**
     * {@inheritDoc}
     */
    public Iterator<Repository> iterator() {
        Repository[] array = new Repository[repositories.values().size()];
        repositories.values().toArray(array);
        Arrays.sort(array, new RepositoryComparator());
        return Arrays.asList(array).iterator();
    }

    /**
     * {@inheritDoc}
     */
    public Integer getRepositoryCount() {
        return this.repositories.size();
    }
}
