/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.bindings.deploymentplan;

import org.ow2.util.plan.bindings.exceptions.InvalidDeploymentException;

/**
 * Extension of the Deployment binding class with additional data
 * (the deployment status).
 * @author mleduque
 */
public abstract class DeploymentPlanFragment extends Deployment {

    /**
     * If the Deployment has been deployed.
     */
    private Boolean deployed = false;

    /**
     * Returns true if the Deployment has been deployed.
     * @return true if the Deployment has been deployed.
     */
    public Boolean isDeployed() {
        return this.deployed;
    }

    /**
     * Sets the deployment state.
     * @param deployed the new state.
     */
    public void setDeployed(Boolean deployed) {
        this.deployed = deployed;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(this.getClass().getSimpleName());
        sb.append("[");
        try {
            sb.append(DeploymentHelper.getId(this));
        } catch (InvalidDeploymentException e) {
            sb.append("<invalid-id>");
        }
        sb.append(", reloadable=");
        try {
            sb.append(DeploymentHelper.isReloadable(this));
        } catch (InvalidDeploymentException e) {
            sb.append("<invalid>");
        }
        sb.append(", useRepository=");
        String repository = null;
        try {
            repository = DeploymentHelper.getRepositoryRef(this);
        } catch (InvalidDeploymentException e) {
            repository = "<invalid-ref>";
        }
        if (repository == null) {
            repository = "<not set>";
        }
        sb.append(repository);
        sb.append("]");

        return sb.toString();
    }
}
